@@ -2,3 +2,8 @@ from ec_tools.basic_tools.colorful_log import ColorfulLog
 from ec_tools.basic_tools.colorful_str import colorful_str
 from ec_tools.basic_tools.procedure import Procedure as procedure
 from ec_tools.basic_tools.replace_dict import ReplaceDict
+
+from ec_tools import basic_tools
+from ec_tools import database
+from ec_tools import image
+from ec_tools import spider
